firefuel
library
Classes
average
Create an object that can be used to compute the average of a specified field
over a range of documents in the result set of a query.
Batch <T extends Serializable >
Chunk <T >
Used to keep track of state when paginating
Clause
Creates a condition to filter your Collection
Collection <T extends Serializable >
CollectionAggregate <T >
Server-side sum and average aggregations over a query, without downloading
matching documents. Wraps Query.aggregate from cloud_firestore.
CollectionCount <T >
Methods used to retrieve primitive values from a collection
CollectionPaginate <R , T extends Serializable >
Get a number of Documents from the Collection
CollectionRead <R , T extends Serializable >
Read a List of T from the Collection
CollectionReference <T extends Object ? >
DocCreate <R , T extends Serializable >
Create a new Document
DocCreateIfNotExist <R , T extends Serializable >
Do some action, then create a Document if it doesn't exist
DocDelete <R >
Delete an existing Document
DocRead <R >
Read a Document
DocReadMany <R >
Read multiple documents by id while preserving the order of the ids.
DocReplace <R , T extends Serializable >
Replace an existing Document
DocumentId
Strips out illegal characters from a string intended to be used as a
document ID in Firestore
DocumentSnapshot <T extends Object ? >
A DocumentSnapshot contains data read from a document in your FirebaseFirestore
database.
DocUpdate <R , T extends Serializable >
Update an existing Document
DocUpdateOrCreate <R , T extends Serializable >
Do some action, then create a Document if it doesn't exist
Either <L , R >
Failure
FieldPath
A FieldPath refers to a field in a document.
FieldValue
Sentinel values that can be used when writing document fields with set() or
update().
Firefuel
FirefuelBatch <T extends Serializable >
FirefuelCollection <T extends Serializable >
FirefuelFailure
FirefuelRepository <T extends Serializable >
FirestoreFailure
GetOptions
An options class that configures the behavior of get() calls on DocumentReference and Query .
Left <L , R >
OrderBy
Creates a condition to order your collection
Query <T extends Object ? >
Represents a Query over the data at a particular location.
QueryDocumentSnapshot <T extends Object ? >
A QueryDocumentSnapshot contains data read from a document in your FirebaseFirestore
database as part of a query.
QuerySnapshot <T extends Object ? >
Contains the results of a query.
It can contain zero or more DocumentSnapshot objects.
Repository <T extends Serializable >
Right <L , R >
Serializable
SetOptions
An options class that configures the behavior of set() calls in DocumentReference,
WriteBatch and Transaction.
SnapshotOptions
Options that configure how data is retrieved from a DocumentSnapshot
(e.g. the desired behavior for server timestamps that have not yet been set to their final value).
sum
Create an object that can be used to compute the sum of a specified field
over a range of documents in the result set of a query.