DocUpdate<R, T extends Serializable> class
abstract
Update an existing Document
R: should return Null or some subset,
i.e. Either<Failure, Null>
- Subclasses: Collection and Repository for subclasses
- Implementations: FirefuelCollection and FirefuelRepository for subclasses
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
arrayRemove(
{required DocumentId docId, required String field, required List< Object?> values}) → Future<R> -
Removes
valuesfrom an array field using Firestore's array remove transform. -
arrayUnion(
{required DocumentId docId, required String field, required List< Object?> values}) → Future<R> -
Adds
valuesto an array field using Firestore's array union transform. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serverTimestamp(
{required DocumentId docId, required String field}) → Future< R> -
Sets
fieldto Firestore's server timestamp. -
toString(
) → String -
A string representation of this object.
inherited
-
update(
{required DocumentId docId, required T value}) → Future< R> - Updates data on the document. Data will be merged with any existing document data.
-
updateFields(
{required DocumentId docId, required Map< String, Object?> fields}) → Future<R> - Updates specific fields on the document.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited